@@ -10,12 +10,17 @@ require Exporter;
 require XSLoader;
 
 our @ISA = qw(Exporter);
-our @EXPORT_OK = qw(minify);
+our @EXPORT_OK = qw(minify minify_utf8 minify_ascii);
 
-our $VERSION = 'v0.5.2';
+our $VERSION = 'v0.6.0';
 
 XSLoader::load( "Text::Minify::XS", $VERSION );
 
+{
+    no strict 'refs';
+    *minify_utf8 = \&minify;
+}
+
 1;
 
 __END__
@@ -30,7 +35,7 @@ Text::Minify::XS - remove indentation and trailing whitespace
 
 =head1 VERSION
 
-version v0.5.2
+version v0.6.0
 
 =head1 SYNOPSIS
 
@@ -38,6 +43,11 @@ version v0.5.2
 
   my $out = minify( $in );
 
+=head1 DESCRIPTION
+
+This is a simple and fast text minifier that removes quickly extra
+whitespace from multi-line text.
+
 =head1 EXPORTS
 
 None by default.
@@ -74,6 +84,24 @@ and changes carriage returns to newlines.
 It does not recognise any form of markup, comments or text quoting.
 Nor does it remove extra whitespace in the middle of the line.
 
+Because it does not recognise any markup, newlines are not removed
+since they may be significant.
+
+=head2 minify_utf8
+
+This is an alias for L</minify>.  It was added in v0.5.3.
+
+=head2 minify_ascii
+
+This is a version of L</minify> that works on ASCII text. It was added in v0.5.3.
+
+If you are only processing 8-bit text, then it should be faster.
+(Rudimentary benchmarks show it is twice as fast as L</minify>.)
+
+Unlike the L</minify>, if the input string has the UTF-8 flag set, the
+resulting string will not.  You should ensure the string is properly
+encoded.
+
 =head1 KNOWN ISSUES
 
 =head2 Malformed UTF-8
